==> nomachine-7.10.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXUsb.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXUsb::BEGIN{package NXUsb;no warnings;require Error;do{
"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}package NXUsb;no warnings;
%usbDB;sub list{(my $extended=(shift (@_)||(0x0621+ 1333-0x0b56)));(my $username
=(shift (@_)||("")));(my (%usbList)=());(my $result=getUsbList ((\%usbList),
$username));if (($result!=(0x0c5b+ 5595-0x2236))){printUsbList ((\%usbList),
$extended);}else{Common::NXMsg::error (
"\x65\x43\x4d\x44\x55\x73\x62\x4c\x69\x73\x74\x46\x61\x69\x6c\x65\x64");}}sub 
add{(my $encodedLine=shift (@_));(my $line=main::urldecode ($encodedLine));(my $usb
=__parseUsbCommandLine ($line));(my $sessionId=Server::getMySessionID ());(my $record
=__createRecord ($sessionId,NXLogin::getCurrentUser (),$usb));(my $result=__add 
($record));(my $hubPort=$$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"});if (($result
==(0x06e7+ 3009-0x12a8))){Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}else{Logger::debug (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x41\x64\x64\x65\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}}sub __createRecord{(my $sessionId=shift (@_));(my $username
=shift (@_));(my $ref_usb=shift (@_));(my $record=(""));($record.=($username.
"\x3a"));($record.=($sessionId."\x3a"));($record.=($$ref_usb{
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65"}."\x3a"));($record.=($$ref_usb{
"\x48\x75\x62\x2d\x50\x6f\x72\x74"}."\x3a"));($record.=($$ref_usb{
"\x53\x74\x61\x74\x75\x73"}."\x3a"));($record.=($$ref_usb{"\x4e\x6f\x64\x65\x73"
}."\x3a"));($record.="\x0a");return ($record);}sub delete{(my $encodedLine=shift
 (@_));(my $line=main::urldecode ($encodedLine));(my $usb=__parseUsbCommandLine 
($line));(my $sessionId=Server::getMySessionID ());(my $hubPort=$$usb{
"\x48\x75\x62\x2d\x50\x6f\x72\x74"});(my $result=__del ($sessionId,$hubPort));if
 (($result==(0x110b+ 4443-0x2266))){Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x6c\x65\x74\x65\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}else{Logger::debug (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x44\x65\x6c\x65\x74\x65\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}}sub deleteBySessionId{(my $sessionId=shift (@_));(my $result
=__del ($sessionId));if (($result==(0x16c7+ 1797-0x1dcc))){Logger::warning (((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x6c\x65\x74\x65\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x2e"));}else{Logger::debug (((
"\x4e\x58\x55\x73\x62\x3a\x20\x44\x65\x6c\x65\x74\x65\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x2e"));}}sub deleteMySession{return (deleteBySessionId (
Server::getMySessionID ()));}sub __parseUsbCommandLine{(my $lineToParse=shift (
@_));($lineToParse=~ s/[\r\n]//g );(my (@line)=split ( /,/ ,$lineToParse,
(0x028a+ 3273-0x0f53)));(my (%usb)=());($usb{
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65"}=$line[(0x1328+ 2214-0x1bce)]);(
$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"}=$line[(0x23ed+ 628-0x2660)]);($usb{
"\x53\x74\x61\x74\x75\x73"}=$line[(0x0adb+ 719-0x0da8)]);($usb{
"\x4e\x6f\x64\x65\x73"}=$line[(0x118b+ 2125-0x19d5)]);return ((\%usb));}sub 
getUsbList{(my $ref_usbList=shift (@_));(my $username=shift (@_));(my $dbFilePath
=NXPaths::getUsbDBPath ());(my $handle=main::nxopen ($dbFilePath,
$NXBits::O_RDONLY));if (defined ($handle)){my ($line);while (main::nxreadLine (
$handle,(\$line))){(my $usb=__parseDBLine ($line));if ($username){if (($username
 eq $$usb{"\x55\x73\x65\x72\x6e\x61\x6d\x65"})){($$ref_usbList{$i++}=$usb);}}
else{($$ref_usbList{$i++}=$usb);}}main::nxclose ($handle);}else{return (
(0x016a+ 9096-0x24f2));}return ((0x11dd+ 479-0x13bb));}sub printUsbList{(my $ref_usbList
=shift (@_));(my $extended=(shift (@_)||(0x1450+ 2289-0x1d41)));(my (@labels)=(
"\x55\x73\x65\x72\x6e\x61\x6d\x65","\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44",
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65",
"\x48\x75\x62\x2d\x50\x6f\x72\x74","\x53\x74\x61\x74\x75\x73"));if ($extended){
push (@labels,"\x4e\x6f\x64\x65\x73");}Common::NXMsg::info (
"\x69\x43\x4d\x44\x55\x73\x62\x4c\x69\x73\x74");return (NXTools::printTable ((
\@labels),$ref_usbList));}sub __add{(my $record=shift (@_));(my $dbFilePath=
NXPaths::getUsbDBPath ());(my $lockHandle=main::lockFileDirect ($dbFilePath,
$NXBits::LOCK_EX));(my $dbHandle=main::nxopen ($dbFilePath,(($NXBits::O_WRONLY+
$NXBits::O_CREAT)+$NXBits::O_APPEND),$NXBits::UserReadWrite));if ((not (defined 
($dbHandle)))){main::unLockFileDirect ($lockHandle);(my $errorString=
libnxh::NXGetErrorString ());Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x66\x69\x6c\x65\x3a\x20"
.$dbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString).
"\x27"));return ((0x03fc+ 1551-0x0a0b));}(my $bytes=main::nxwrite ($dbHandle,
$record));if (($bytes==(-(0x03b5+ 8201-0x23bd)))){(my $errorString=
libnxh::NXGetErrorString ());main::nxclose ($dbHandle);main::unLockFileDirect (
$lockHandle);Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x3a\x20"
.$dbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString).
"\x27"));return ((0x084d+ 6108-0x2029));}main::nxclose ($dbHandle);
main::unLockFileDirect ($lockHandle);return ((0x1289+ 345-0x13e1));}sub __del{(my $sessionId
=shift (@_));(my $hubPort=shift (@_));(my $dbFilePath=NXPaths::getUsbDBPath ());
(my $flag_del=(0x0361+ 896-0x06e1));(my $lockHandle=main::lockFileDirect (
$dbFilePath,$NXBits::LOCK_EX));(my $dbHandle=main::nxopen ($dbFilePath,
$NXBits::O_RDONLY,(0x131b+ 655-0x15aa)));if ((not (defined ($dbHandle)))){(my $errorString
=libnxh::NXGetErrorString ());main::unLockFileDirect ($lockHandle);
Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x3a\x20"
.$dbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString).
"\x27"));return ((0x047b+ 8114-0x242d));}(my $tempdbFilePath=(($dbFilePath.
"\x2e\x74\x6d\x70\x2e").$ $));
 if (Common::NXFile::isExists ($tempdbFilePath)){
unlink ($tempdbFilePath);}(my $tmpHandle=main::nxopen ($tempdbFilePath,((
$NXBits::O_CREAT+$NXBits::O_WRONLY)+$NXBits::O_APPEND),$NXBits::UserReadWrite));
if ((not (defined ($tmpHandle)))){(my $errorString=libnxh::NXGetErrorString ());
main::nxclose ($dbHandle);main::unLockFileDirect ($lockHandle);Logger::warning (
((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x3a\x20"
.$tempdbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").
$errorString)."\x27"));return ((0x05fb+ 2718-0x1099));}&try (sub{my ($line);
while (main::nxreadLine ($dbHandle,(\$line))){(my $usb=__parseDBLine ($line));(
$usbDB{$$usb{"\x55\x73\x65\x72\x6e\x61\x6d\x65"}}=$usb);if ((($sessionId ne 
$$usb{"\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44"})or ($hubPort and ($hubPort ne 
$$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"})))){
Common::NXCore::nxwriteOrThrowException ($tmpHandle,$line);}}},&otherwise (sub{(my $error
=shift (@_));main::nxclose ($tmpHandle);main::nxclose ($dbHandle);
main::unLockFileDirect ($lockHandle);Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x3a\x20"
.$tempdbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$error).
"\x27"));return ((0x0b94+ 2447-0x1523));}));main::nxclose ($tmpHandle);
main::nxclose ($dbHandle);if ((not (Common::NXFile::renameFile ($tempdbFilePath,
$dbFilePath)))){(my $errorString=libnxh::NXGetErrorString ());
main::unLockFileDirect ($lockHandle);Logger::warning (((((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x3a\x3a\x20"
.$tempdbFilePath)."\x20\x74\x6f\x3a\x20").$dbFilePath).
"\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString)."\x27"));
return ((0x14f2+ 458-0x16bc));}main::unLockFileDirect ($lockHandle);return (
(0x00a6+ 3926-0x0ffb));}sub __parseDBLine{(my $lineToParse=shift (@_));(
$lineToParse=~ s/[\r\n]//g );(my (@line)=split ( /:/ ,$lineToParse,
(0x09aa+ 490-0x0b94)));(my (%usb)=());($usb{"\x55\x73\x65\x72\x6e\x61\x6d\x65"}=
$line[(0x0695+ 1888-0x0df5)]);($usb{"\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44"}=
$line[(0x1d95+ 1521-0x2385)]);($usb{
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65"}=$line[(0x1044+ 4554-0x220c)]);(
$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"}=$line[(0x02f8+ 7197-0x1f12)]);($usb{
"\x53\x74\x61\x74\x75\x73"}=$line[(0x03f4+ 166-0x0496)]);($usb{
"\x4e\x6f\x64\x65\x73"}=$line[(0x0043+ 6068-0x17f2)]);return ((\%usb));}
"\x3f\x3f\x3f";

==> nomachine-8.0.168-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXUsb.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXUsb::BEGIN{package NXUsb;no warnings;require Error;do{
"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}package NXUsb;no warnings;
%usbDB;sub list{(my $extended=(shift (@_)||(0x0761+ 5605-0x1d46)));(my $username
=(shift (@_)||("")));(my (%usbList)=());(my $result=getUsbList ((\%usbList),
$username));if (($result!=(0x147b+ 1374-0x19d9))){printUsbList ((\%usbList),
$extended);}else{Common::NXMsg::error (
"\x65\x43\x4d\x44\x55\x73\x62\x4c\x69\x73\x74\x46\x61\x69\x6c\x65\x64");}}sub 
add{(my $encodedLine=shift (@_));(my $line=main::urldecode ($encodedLine));(my $usb
=__parseUsbCommandLine ($line));(my $sessionId=Server::getMySessionID ());(my $record
=__createRecord ($sessionId,NXLogin::getCurrentUser (),$usb));(my $result=__add 
($record));(my $hubPort=$$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"});if (($result
==(0x0ab3+ 763-0x0dae))){Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}else{Logger::debug (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x41\x64\x64\x65\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}}sub __createRecord{(my $sessionId=shift (@_));(my $username
=shift (@_));(my $ref_usb=shift (@_));(my $record=(""));($record.=($username.
"\x3a"));($record.=($sessionId."\x3a"));($record.=($$ref_usb{
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65"}."\x3a"));($record.=($$ref_usb{
"\x48\x75\x62\x2d\x50\x6f\x72\x74"}."\x3a"));($record.=($$ref_usb{
"\x53\x74\x61\x74\x75\x73"}."\x3a"));($record.=($$ref_usb{"\x4e\x6f\x64\x65\x73"
}."\x3a"));($record.="\x0a");return ($record);}sub delete{(my $encodedLine=shift
 (@_));(my $line=main::urldecode ($encodedLine));(my $usb=__parseUsbCommandLine 
($line));(my $sessionId=Server::getMySessionID ());(my $hubPort=$$usb{
"\x48\x75\x62\x2d\x50\x6f\x72\x74"});(my $result=__del ($sessionId,$hubPort));if
 (($result==(0x0b91+ 6233-0x23ea))){Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x6c\x65\x74\x65\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}else{Logger::debug (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x44\x65\x6c\x65\x74\x65\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}}sub deleteBySessionId{(my $sessionId=shift (@_));(my $result
=__del ($sessionId));if (($result==(0x0782+ 372-0x08f6))){Logger::warning (((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x6c\x65\x74\x65\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x2e"));}else{Logger::debug (((
"\x4e\x58\x55\x73\x62\x3a\x20\x44\x65\x6c\x65\x74\x65\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x2e"));}}sub deleteMySession{return (deleteBySessionId (
Server::getMySessionID ()));}sub __parseUsbCommandLine{(my $lineToParse=shift (
@_));($lineToParse=~ s/[\r\n]//g );(my (@line)=split ( /,/ ,$lineToParse,
(0x0a8f+ 884-0x0e03)));(my (%usb)=());($usb{
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65"}=$line[(0x0743+ 7994-0x267d)]);(
$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"}=$line[(0x01d2+ 2046-0x09cf)]);($usb{
"\x53\x74\x61\x74\x75\x73"}=$line[(0x044d+ 3543-0x1222)]);($usb{
"\x4e\x6f\x64\x65\x73"}=$line[(0x0b33+ 4280-0x1be8)]);return ((\%usb));}sub 
getUsbList{(my $ref_usbList=shift (@_));(my $username=shift (@_));(my $dbFilePath
=NXPaths::getUsbDBPath ());(my $handle=main::nxopen ($dbFilePath,
$NXBits::O_RDONLY));if (defined ($handle)){my ($line);while (main::nxreadLine (
$handle,(\$line))){(my $usb=__parseDBLine ($line));if ($username){if (($username
 eq $$usb{"\x55\x73\x65\x72\x6e\x61\x6d\x65"})){($$ref_usbList{$i++}=$usb);}}
else{($$ref_usbList{$i++}=$usb);}}main::nxclose ($handle);}else{return (
(0x0cbc+ 3521-0x1a7d));}return ((0x08b3+ 2924-0x141e));}sub printUsbList{(my $ref_usbList
=shift (@_));(my $extended=(shift (@_)||(0x0008+ 1415-0x058f)));(my (@labels)=(
"\x55\x73\x65\x72\x6e\x61\x6d\x65","\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44",
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65",
"\x48\x75\x62\x2d\x50\x6f\x72\x74","\x53\x74\x61\x74\x75\x73"));if ($extended){
push (@labels,"\x4e\x6f\x64\x65\x73");}Common::NXMsg::info (
"\x69\x43\x4d\x44\x55\x73\x62\x4c\x69\x73\x74");return (NXTools::printTable ((
\@labels),$ref_usbList));}sub __add{(my $record=shift (@_));(my $dbFilePath=
NXPaths::getUsbDBPath ());(my $lockHandle=main::lockFileDirect ($dbFilePath,
$NXBits::LOCK_EX));(my $dbHandle=main::nxopen ($dbFilePath,(($NXBits::O_WRONLY+
$NXBits::O_CREAT)+$NXBits::O_APPEND),$NXBits::UserReadWrite));if ((not (defined 
($dbHandle)))){main::unLockFileDirect ($lockHandle);(my $errorString=
libnxh::NXGetErrorString ());Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x66\x69\x6c\x65\x3a\x20"
.$dbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString).
"\x27"));return ((0x0ecd+ 530-0x10df));}(my $bytes=main::nxwrite ($dbHandle,
$record));if (($bytes==(-(0x0a41+ 1934-0x11ce)))){(my $errorString=
libnxh::NXGetErrorString ());main::nxclose ($dbHandle);main::unLockFileDirect (
$lockHandle);Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x3a\x20"
.$dbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString).
"\x27"));return ((0x0080+ 1996-0x084c));}main::nxclose ($dbHandle);
main::unLockFileDirect ($lockHandle);return ((0x14cb+ 3715-0x234d));}sub __del{(my $sessionId
=shift (@_));(my $hubPort=shift (@_));(my $dbFilePath=NXPaths::getUsbDBPath ());
(my $flag_del=(0x0be9+ 2786-0x16cb));(my $lockHandle=main::lockFileDirect (
$dbFilePath,$NXBits::LOCK_EX));(my $dbHandle=main::nxopen ($dbFilePath,
$NXBits::O_RDONLY,(0x0a0c+ 359-0x0b73)));if ((not (defined ($dbHandle)))){(my $errorString
=libnxh::NXGetErrorString ());main::unLockFileDirect ($lockHandle);
Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x3a\x20"
.$dbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString).
"\x27"));return ((0x0054+ 5113-0x144d));}(my $tempdbFilePath=(($dbFilePath.
"\x2e\x74\x6d\x70\x2e").$ $));
 if (Common::NXFile::isExists ($tempdbFilePath)){
unlink ($tempdbFilePath);}(my $tmpHandle=main::nxopen ($tempdbFilePath,((
$NXBits::O_CREAT+$NXBits::O_WRONLY)+$NXBits::O_APPEND),$NXBits::UserReadWrite));
if ((not (defined ($tmpHandle)))){(my $errorString=libnxh::NXGetErrorString ());
main::nxclose ($dbHandle);main::unLockFileDirect ($lockHandle);Logger::warning (
((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x3a\x20"
.$tempdbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").
$errorString)."\x27"));return ((0x14c6+ 3857-0x23d7));}&try (sub{my ($line);
while (main::nxreadLine ($dbHandle,(\$line))){(my $usb=__parseDBLine ($line));(
$usbDB{$$usb{"\x55\x73\x65\x72\x6e\x61\x6d\x65"}}=$usb);if ((($sessionId ne 
$$usb{"\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44"})or ($hubPort and ($hubPort ne 
$$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"})))){
Common::NXCore::nxwriteOrThrowException ($tmpHandle,$line);}}},&otherwise (sub{(my $error
=shift (@_));main::nxclose ($tmpHandle);main::nxclose ($dbHandle);
main::unLockFileDirect ($lockHandle);Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x3a\x20"
.$tempdbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$error).
"\x27"));return ((0x0b9d+ 1746-0x126f));}));main::nxclose ($tmpHandle);
main::nxclose ($dbHandle);if ((not (Common::NXFile::renameFile ($tempdbFilePath,
$dbFilePath)))){(my $errorString=libnxh::NXGetErrorString ());
main::unLockFileDirect ($lockHandle);Logger::warning (((((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x3a\x3a\x20"
.$tempdbFilePath)."\x20\x74\x6f\x3a\x20").$dbFilePath).
"\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString)."\x27"));
return ((0x04a6+ 7245-0x20f3));}main::unLockFileDirect ($lockHandle);return (
(0x12cf+ 2486-0x1c84));}sub __parseDBLine{(my $lineToParse=shift (@_));(
$lineToParse=~ s/[\r\n]//g );(my (@line)=split ( /:/ ,$lineToParse,
(0x09dc+ 4212-0x1a50)));(my (%usb)=());($usb{"\x55\x73\x65\x72\x6e\x61\x6d\x65"}
=$line[(0x0fb0+ 2522-0x198a)]);($usb{"\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44"}
=$line[(0x1365+ 4707-0x25c7)]);($usb{
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65"}=$line[(0x0d13+ 3726-0x1b9f)]);(
$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"}=$line[(0x194c+ 599-0x1ba0)]);($usb{
"\x53\x74\x61\x74\x75\x73"}=$line[(0x0a9c+ 884-0x0e0c)]);($usb{
"\x4e\x6f\x64\x65\x73"}=$line[(0x0245+ 2309-0x0b45)]);return ((\%usb));}
"\x3f\x3f\x3f";
